@@ -23,6 +23,7 @@
 #include "globus_net_manager_attr.h"
 #include "globus_net_manager_context.h"
 
+GlobusDebugDeclare(GLOBUS_XIO_NET_MANAGER);
 GlobusDebugDefine(GLOBUS_XIO_NET_MANAGER);
 GlobusXIODeclareDriver(net_manager);
 
@@ -101,6 +102,8 @@ globus_l_xio_net_manager_deactivate(void);
 
 #include "version.h"
 
+GlobusXIODeclareModule(net_manager);
+
 GlobusXIODefineModule(net_manager) =
 {
     "globus_xio_net_manager",
@@ -341,7 +344,6 @@ new_context_fail:
 new_attr_init_fail:
 strdup_task_id_fail:
 strdup_scope_fail:
-no_scope:
 no_equals:
     free(new_task_id);
     free(scope);
@@ -834,12 +836,11 @@ globus_l_xio_net_manager_server_init(
     globus_xio_operation_t              op)
 {
     globus_result_t                     result = GLOBUS_SUCCESS;
-    globus_l_xio_net_manager_attr_t    *tmp_attr = NULL;
     globus_net_manager_attr_t          *transport_attrs = NULL,
                                        *new_attrs = NULL;
     globus_l_xio_net_manager_server_t  *server = NULL;
     char                               *new_contact_string = NULL;
-    globus_xio_contact_t                new_contact_info = {0};
+    globus_xio_contact_t                new_contact_info = {NULL};
 
     if (!driver_attr)
     {
@@ -946,7 +947,6 @@ get_attr_array_fail:
     {
         globus_l_xio_net_manager_attr_destroy(server->attr);
 copy_attr_fail:
-init_attr_fail:
 get_driver_name_fail:
         free(server);
     }
@@ -973,7 +973,6 @@ globus_l_xio_net_manager_server_accept_callback(
         link = NULL;
     }
 
-accept_fail:
     globus_xio_driver_finished_accept(op, link, result);
 }
 /* globus_l_xio_net_manager_server_accept_callback() */
@@ -986,7 +985,6 @@ globus_l_xio_net_manager_server_accept(
 {
     globus_result_t                     result = GLOBUS_SUCCESS;
     globus_l_xio_net_manager_server_t  *server = driver_server;
-    globus_l_xio_net_manager_attr_t    *attr = NULL;
     globus_l_xio_net_manager_link_t    *link = NULL;
     globus_net_manager_attr_t          *new_attr_array = NULL;
 
@@ -1162,7 +1160,6 @@ globus_l_xio_net_manager_connect_callback(
     {
 post_connect_fail:
         free(handle->remote_contact);
-get_remote_contact_fail:
         free(handle->local_contact);
     }
 get_local_contact_fail:
@@ -1191,7 +1188,7 @@ globus_l_xio_net_manager_connect(
     char                               *contact_out = NULL;
     char                               *string_opts = NULL;
     globus_net_manager_attr_t          *attrs = NULL, *attr_array_out = NULL;
-    globus_xio_contact_t                new_contact_info = {0};
+    globus_xio_contact_t                new_contact_info = {NULL};
     
     if (!driver_attr)
     {
@@ -1328,7 +1325,6 @@ globus_l_xio_net_manager_accept_callback(
     globus_l_xio_net_manager_handle_t  *handle = NULL;
     char                               *string_opts = NULL;
     globus_net_manager_attr_t          *attrs = NULL, *attr_array_out = NULL;
-    globus_xio_contact_t                new_contact_info = {0};
     globus_xio_driver_handle_t          driver_handle =
                 globus_xio_operation_get_driver_handle(op);
 
@@ -1428,7 +1424,6 @@ array_from_string_fail:
     {
 get_string_opts_fail:
         globus_l_xio_net_manager_attr_destroy(handle->attr);
-attr_copy_fail:
         free(handle->remote_contact);
 get_remote_contact_fail:
         free(handle->local_contact);
@@ -1452,13 +1447,11 @@ globus_l_xio_net_manager_accept(
 {
     globus_result_t                     result = GLOBUS_SUCCESS;
     globus_l_xio_net_manager_link_t    *link = driver_link;
-    globus_l_xio_net_manager_link_t    *copy_link = NULL;
 
     result = globus_xio_driver_pass_open(op, contact_info,
             globus_l_xio_net_manager_accept_callback,
             link);
 
-copy_link_malloc_fail:
     return result;
 }
 /* globus_l_xio_net_manager_accept() */
@@ -1516,7 +1509,6 @@ globus_l_xio_net_manager_close_cb(
                 handle->attr->attr_array);
     }
     globus_l_xio_net_manager_attr_destroy(handle->attr);
-get_attr_array_fail:
     free(handle->remote_contact);
     free(handle->local_contact);
     free(handle);
@@ -1534,8 +1526,6 @@ globus_l_xio_net_manager_close(
     globus_l_xio_net_manager_handle_t  *handle = driver_specific_handle;
     globus_result_t                     result = GLOBUS_SUCCESS;
     globus_net_manager_attr_t          *transport_opts = NULL;
-    globus_xio_driver_handle_t          driver_handle =
-            globus_xio_operation_get_driver_handle(op);
 
     if (!handle)
     {
